@@ -5,28 +5,86 @@ fn main() {
     if asciiart !="NOASCII" {
         println!("{}", asciiart.bright_cyan());
     }
-    let distro = get_distro();
-    let ost = "OS: ".bright_yellow();
+    
+    let ost = "OS: ".magenta();
     let totmem = "Total RAM (Gb): ".blue();
-    let avmem = "Available RAM (Gb): ".green();
-    let usedmem = "Used RAM (Gb): ".red();
-    let totalroot = "Total Root Partition (Gb): ".blue();
-    let avroot = "Available Root Partition (Gb): ".green();
-    let usedroot = "Used Root Partition (Gb): ".yellow();
+    let avmem = "Available RAM (Gb): ".blue();
+    let usedmem = "Used RAM (Gb): ".blue();
+    let totalroot = "Total Root Partition (Gb): ".red();
+    let avroot = "Available Root Partition (Gb): ".red();
+    let usedroot = "Used Root Partition (Gb): ".red();
     let cpu = "CPU: ".magenta();
-    let desktop = "Desktop: ".bright_cyan();
-    println!("{ost}{}", distro);
+    let desktop = "Desktop: ".yellow();
+    let session_type = "Session Type: ".yellow();
+    let username = "Username: ".yellow();
+    let terminal = "Terminal: ".yellow();
+    let editor = "Editor: ".yellow();
+    println!("{}","=======================".green());
+    println!("{ost}{}", get_distro());
+    println!("{cpu}{}", get_cpu_name());
     println!("{totmem}{}", get_total_ram());   
     println!("{avmem}{}", get_available_ram());
     println!("{usedmem}{}", get_used_ram());
     println!("{totalroot}{}", get_total_disk());
     println!("{avroot}{}", get_available_disk());
-    println!("{usedroot}{}", get_used_disk());
-    println!("{cpu}{}", get_cpu_name());
+    println!("{usedroot}{}", get_used_disk());    
     println!("{desktop}{}", get_de());
+    println!("{session_type}{}", get_session_type());
+    println!("{username}{}", get_user());
+    println!("{terminal}{}", get_terminal());
+    println!("{editor}{}", get_editor());
+    println!("{}","=======================".green());
 }
 
 
+fn get_editor() -> String {
+    let editor = env::var("EDITOR");
+    match editor {
+        Ok(val) => val,
+        Err(_) => "Not Set".to_string(),
+    }
+}
+
+fn get_terminal() -> String {
+    let de = get_de();
+    if de!="Unknown or tty"{
+        let term = env::var("TERM_PROGRAM").unwrap();
+        let term = term.to_string();
+        term
+    }
+    else {
+        "Unknown".to_string()
+    }
+}
+
+fn get_user() -> String {
+    let de = get_de();
+    if de!="Unknown or tty"{
+        let user = env::var("USERNAME").unwrap();
+        let user = user.to_string();
+        return user;
+    }
+    else {
+        return "Unknown".to_string();
+    }
+}
+
+fn get_session_type() -> String {
+    let de = get_de();
+    if de!="Unknown or tty"{
+        let session_type = env::var("XDG_SESSION_TYPE").unwrap();
+        if session_type!="" {
+            return session_type;
+        }    
+        else{
+            return "Unknown or tty".to_string();
+        }
+    }
+    else {
+        return "Unknown or tty".to_string();
+    }
+}
+
 fn get_ascii_art() -> String {
     let homedir = env::var("HOME").unwrap_or("".to_string());
     let ascii_art_path=homedir+"/.config/qfetch/ascii_art.txt";
